==> owncloud-9.0.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_sharing/l10n/pl.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Współdzielenie między serwerami nie jest uruchomione na tym serwerze",
    "The mountpoint name contains invalid characters." : "Nazwa zamontowanego zasobu zawiera niedozwolone znaki.",
    "Invalid or untrusted SSL certificate" : "Niewłaściwy lub niezaufany certyfikat SSL",
    "Could not authenticate to remote share, password might be wrong" : "Nie można zalogować do zdalnego zasobu, hasło może być niepoprawne",
    "Storage not valid" : "Zasób nie jest prawidłowy",
    "Couldn't add remote share" : "Nie można dodać zdalnego folderu",
    "Shared with you" : "Współdzielony z Tobą",
    "Shared with others" : "Współdzielony z innymi",
    "Shared by link" : "Współdzielony linkiem",
    "Nothing shared with you yet" : "Nie masz jeszcze nic udostępnionego",
    "Files and folders others share with you will show up here" : "Pliki i foldery udostępnione Tobie przez innych wyświetlą się tutaj",
    "Nothing shared yet" : "Jeszcze nic nie udostępniono",
    "Files and folders you share will show up here" : "Plik i foldery, które udostępniasz, pokażą się tutaj",
    "No shared links" : "Brak udostępnionych odnośników",
    "Files and folders you share by link will show up here" : "Plik i foldery, które udostępniasz, pokażą się tutaj",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Czy chcesz dodać udział zdalny {name} od {owner}@{remote}?",
    "Remote share" : "Zdalny zasób",
    "Remote share password" : "Hasło do zdalnego zasobu",
    "Cancel" : "Anuluj",
    "Add remote share" : "Dodaj zdalny zasób",
    "Invalid ownCloud url" : "Błędny adres URL",
    "Shared by" : "Udostępniane przez",
    "Sharing" : "Udostępnianie",
    "A file or folder has been <strong>shared</strong>" : "Plik lub folder stał się <strong>współdzielony</strong>",
    "You shared %1$s with %2$s" : "Współdzielisz %1$s z %2$s",
    "You shared %1$s with group %2$s" : "Współdzielisz %1$s z grupą %2$s",
    "You shared %1$s via link" : "Udostępniasz %1$s przez link",
    "%2$s shared %1$s with you" : "%2$s współdzieli %1$s z Tobą",
    "Shares" : "Udziały",
    "Accept" : "Akceptuj",
    "This share is password-protected" : "Udział ten jest chroniony hasłem",
    "The password is wrong. Try again." : "To hasło jest niewłaściwe. Spróbuj ponownie.",
    "Password" : "Hasło",
    "No entries found in this folder" : "Brak wpisów w tym folderze",
    "Name" : "Nazwa",
    "Share time" : "Czas współdzielenia",
    "Sorry, this link doesn’t seem to work anymore." : "Przepraszamy ale wygląda na to, że ten link już nie działa.",
    "Reasons might be:" : "Możliwe powody:",
    "the item was removed" : "element został usunięty",
    "the link expired" : "link wygasł",
    "sharing is disabled" : "udostępnianie jest wyłączone",
    "For more info, please ask the person who sent this link." : "Aby uzyskać więcej informacji proszę poprosić osobę, która wysłał ten link.",
    "Add to your ownCloud" : "Dodaj do twojego ownCloud",
    "Download" : "Pobierz",
    "Download %s" : "Pobierz %s",
    "Direct link" : "Bezpośredni link",
    "Open documentation" : "Otwórz dokumentację",
    "Add to your website" : "Dodaj do swojej strony"
},
"nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-9.1.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_sharing/l10n/pl.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Współdzielenie między serwerami nie jest uruchomione na tym serwerze",
    "The mountpoint name contains invalid characters." : "Nazwa zamontowanego zasobu zawiera niedozwolone znaki.",
    "Invalid or untrusted SSL certificate" : "Niewłaściwy lub niezaufany certyfikat SSL",
    "Could not authenticate to remote share, password might be wrong" : "Nie można zalogować do zdalnego zasobu, hasło może być niepoprawne",
    "Storage not valid" : "Zasób nie jest prawidłowy",
    "Couldn't add remote share" : "Nie można dodać zdalnego folderu",
    "Shared with you" : "Współdzielony z Tobą",
    "Shared with others" : "Współdzielony z innymi",
    "Shared by link" : "Współdzielony linkiem",
    "Nothing shared with you yet" : "Nie masz jeszcze nic udostępnionego",
    "Files and folders others share with you will show up here" : "Pliki i foldery udostępnione Tobie przez innych wyświetlą się tutaj",
    "Nothing shared yet" : "Jeszcze nic nie udostępniono",
    "Files and folders you share will show up here" : "Plik i foldery, które udostępniasz, pokażą się tutaj",
    "No shared links" : "Brak udostępnionych odnośników",
    "Files and folders you share by link will show up here" : "Plik i foldery, które udostępniasz, pokażą się tutaj",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Czy chcesz dodać udział zdalny {name} od {owner}@{remote}?",
    "Remote share" : "Zdalny zasób",
    "Remote share password" : "Hasło do zdalnego zasobu",
    "Cancel" : "Anuluj",
    "Add remote share" : "Dodaj zdalny zasób",
    "No ownCloud installation (7 or higher) found at {remote}" : "Nie znaleziono instalacji ownCloud (w wersji 7 lub nowszej) na {remote}",
    "Invalid ownCloud url" : "Błędny adres URL",
    "Shared by" : "Udostępniane przez",
    "Sharing" : "Udostępnianie",
    "Public link sharing is disabled by the administrator" : "Udostępnianie linków publicznych zostało zablokowane przez twojego administratora",
    "Public upload disabled by the administrator" : "Publiczne wczytywanie zostało zablokowane przez twojego administratora",
    "Public upload is only possible for publicly shared folders" : "Publiczne wczytywanie jest możliwe wyłącznie do katalogów publicznych",
    "A file or folder has been <strong>shared</strong>" : "Plik lub folder stał się <strong>współdzielony</strong>",
    "You shared %1$s with %2$s" : "Współdzielisz %1$s z %2$s",
    "You shared %1$s with group %2$s" : "Współdzielisz %1$s z grupą %2$s",
    "You shared %1$s via link" : "Udostępniasz %1$s przez link",
    "%2$s shared %1$s with you" : "%2$s współdzieli %1$s z Tobą",
    "%2$s removed the share for %1$s" : "%2$s usunął udział dla %1$s",
    "Shares" : "Udziały",
    "This share is password-protected" : "Udział ten jest chroniony hasłem",
    "The password is wrong. Try again." : "To hasło jest niewłaściwe. Spróbuj ponownie.",
    "Password" : "Hasło",
    "No entries found in this folder" : "Brak wpisów w tym folderze",
    "Name" : "Nazwa",
    "Share time" : "Czas współdzielenia",
    "Sorry, this link doesn’t seem to work anymore." : "Przepraszamy ale wygląda na to, że ten link już nie działa.",
    "Reasons might be:" : "Możliwe powody:",
    "the item was removed" : "element został usunięty",
    "the link expired" : "link wygasł",
    "sharing is disabled" : "udostępnianie jest wyłączone",
    "For more info, please ask the person who sent this link." : "Aby uzyskać więcej informacji proszę poprosić osobę, która wysłał ten link.",
    "Add to your ownCloud" : "Dodaj do twojego ownCloud",
    "Download" : "Pobierz",
    "Download %s" : "Pobierz %s",
    "Direct link" : "Bezpośredni link"
},
"nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
